#!/bin/bash


#  slackbuild script for Bibletime
# Author: Mark Tucker
# Created: Aug 27, 2005
# Changes:
#        Aug 27, 2005 - initial creation
#
#----------------------------------------------------------------------

umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="bibletime-1.5.tar.bz2"
pkgname="bibletime"
pkgver="1.5"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xjf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS


#----------------------------------------
# Build the package and install
#----------------------------------------
# configure 
conf_opts="--prefix=/opt/kde"
run_configure $conf_opts

# !!!!!!!!!!!!!!! fix stuff !!!!!!!!!!!!!!!!!!!!
echo "#include <algorithm>" > tmp.file
echo "using namespace std;" >> tmp.file
cat $builddir/bibletime/backend/creferencemanager.cpp >> tmp.file
rm $builddir/bibletime/backend/creferencemanager.cpp 
mv -v  tmp.file $builddir/bibletime/backend/creferencemanager.cpp 
# !!!!!!!!!!!!!!! fix stuff !!!!!!!!!!!!!!!!!!!!


# make
run_make

# Set target directory
set_target

# install
run_makeinstall


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
             |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver 
$pkgname:
$pkgname: BibleTime is a Bible study application for Linux. It is based on the
$pkgname: K Desktop   Environment and uses the Sword programming library to 
$pkgname: work with Bible texts, commentaries, dictionaries and books 
$pkgname: provided by the Crosswire Bible Society.
$pkgname:
$pkgname:
$pkgname: http://www.bibletime.info
$pkgname:
$pkgname: Packaged by $realname for $slackver / KDE 3.4.2
END

# create documentation directory
create_docdir

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# check for uncompressed man pages
compr_man

# makepkg
create_pkg

exit
